// Copyright 2026 Google LLC.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// Code generated file. DO NOT EDIT.

// Package assuredworkloads provides access to the Assured Workloads API.
//
// For product documentation, see: https://cloud.google.com/learnmoreurl
//
// # Library status
//
// These client libraries are officially supported by Google. However, this
// library is considered complete and is in maintenance mode. This means
// that we will address critical bugs and security issues but will not add
// any new features.
//
// When possible, we recommend using our newer
// [Cloud Client Libraries for Go](https://pkg.go.dev/cloud.google.com/go)
// that are still actively being worked and iterated on.
//
// # Creating a client
//
// Usage example:
//
//	import "google.golang.org/api/assuredworkloads/v1"
//	...
//	ctx := context.Background()
//	assuredworkloadsService, err := assuredworkloads.NewService(ctx)
//
// In this example, Google Application Default Credentials are used for
// authentication. For information on how to create and obtain Application
// Default Credentials, see https://developers.google.com/identity/protocols/application-default-credentials.
//
// # Other authentication options
//
// To use an API key for authentication (note: some APIs do not support API
// keys), use [google.golang.org/api/option.WithAPIKey]:
//
//	assuredworkloadsService, err := assuredworkloads.NewService(ctx, option.WithAPIKey("AIza..."))
//
// To use an OAuth token (e.g., a user token obtained via a three-legged OAuth
// flow, use [google.golang.org/api/option.WithTokenSource]:
//
//	config := &oauth2.Config{...}
//	// ...
//	token, err := config.Exchange(ctx, ...)
//	assuredworkloadsService, err := assuredworkloads.NewService(ctx, option.WithTokenSource(config.TokenSource(ctx, token)))
//
// See [google.golang.org/api/option.ClientOption] for details on options.
package assuredworkloads // import "google.golang.org/api/assuredworkloads/v1"

import (
	"bytes"
	"context"
	"encoding/json"
	"errors"
	"fmt"
	"io"
	"log/slog"
	"net/http"
	"net/url"
	"strconv"
	"strings"

	"github.com/googleapis/gax-go/v2/internallog"
	googleapi "google.golang.org/api/googleapi"
	internal "google.golang.org/api/internal"
	gensupport "google.golang.org/api/internal/gensupport"
	option "google.golang.org/api/option"
	internaloption "google.golang.org/api/option/internaloption"
	htransport "google.golang.org/api/transport/http"
)

// Always reference these packages, just in case the auto-generated code
// below doesn't.
var _ = bytes.NewBuffer
var _ = strconv.Itoa
var _ = fmt.Sprintf
var _ = json.NewDecoder
var _ = io.Copy
var _ = url.Parse
var _ = gensupport.MarshalJSON
var _ = googleapi.Version
var _ = errors.New
var _ = strings.Replace
var _ = context.Canceled
var _ = internaloption.WithDefaultEndpoint
var _ = internal.Version
var _ = internallog.New

const apiId = "assuredworkloads:v1"
const apiName = "assuredworkloads"
const apiVersion = "v1"
const basePath = "https://assuredworkloads.googleapis.com/"
const basePathTemplate = "https://assuredworkloads.UNIVERSE_DOMAIN/"
const mtlsBasePath = "https://assuredworkloads.mtls.googleapis.com/"

// OAuth2 scopes used by this API.
const (
	// See, edit, configure, and delete your Google Cloud data and see the email
	// address for your Google Account.
	CloudPlatformScope = "https://www.googleapis.com/auth/cloud-platform"
)

// NewService creates a new Service.
func NewService(ctx context.Context, opts ...option.ClientOption) (*Service, error) {
	scopesOption := internaloption.WithDefaultScopes(
		"https://www.googleapis.com/auth/cloud-platform",
	)
	// NOTE: prepend, so we don't override user-specified scopes.
	opts = append([]option.ClientOption{scopesOption}, opts...)
	opts = append(opts, internaloption.WithDefaultEndpoint(basePath))
	opts = append(opts, internaloption.WithDefaultEndpointTemplate(basePathTemplate))
	opts = append(opts, internaloption.WithDefaultMTLSEndpoint(mtlsBasePath))
	opts = append(opts, internaloption.EnableNewAuthLibrary())
	client, endpoint, err := htransport.NewClient(ctx, opts...)
	if err != nil {
		return nil, err
	}
	s := &Service{client: client, BasePath: basePath, logger: internaloption.GetLogger(opts)}
	s.Organizations = NewOrganizationsService(s)
	if endpoint != "" {
		s.BasePath = endpoint
	}
	return s, nil
}

// New creates a new Service. It uses the provided http.Client for requests.
//
// Deprecated: please use NewService instead.
// To provide a custom HTTP client, use option.WithHTTPClient.
// If you are using google.golang.org/api/googleapis/transport.APIKey, use option.WithAPIKey with NewService instead.
func New(client *http.Client) (*Service, error) {
	if client == nil {
		return nil, errors.New("client is nil")
	}
	return NewService(context.TODO(), option.WithHTTPClient(client))
}

type Service struct {
	client    *http.Client
	logger    *slog.Logger
	BasePath  string // API endpoint base URL
	UserAgent string // optional additional User-Agent fragment

	Organizations *OrganizationsService
}

func (s *Service) userAgent() string {
	if s.UserAgent == "" {
		return googleapi.UserAgent
	}
	return googleapi.UserAgent + " " + s.UserAgent
}

func NewOrganizationsService(s *Service) *OrganizationsService {
	rs := &OrganizationsService{s: s}
	rs.Locations = NewOrganizationsLocationsService(s)
	return rs
}

type OrganizationsService struct {
	s *Service

	Locations *OrganizationsLocationsService
}

func NewOrganizationsLocationsService(s *Service) *OrganizationsLocationsService {
	rs := &OrganizationsLocationsService{s: s}
	rs.Operations = NewOrganizationsLocationsOperationsService(s)
	rs.Workloads = NewOrganizationsLocationsWorkloadsService(s)
	return rs
}

type OrganizationsLocationsService struct {
	s *Service

	Operations *OrganizationsLocationsOperationsService

	Workloads *OrganizationsLocationsWorkloadsService
}

func NewOrganizationsLocationsOperationsService(s *Service) *OrganizationsLocationsOperationsService {
	rs := &OrganizationsLocationsOperationsService{s: s}
	return rs
}

type OrganizationsLocationsOperationsService struct {
	s *Service
}

func NewOrganizationsLocationsWorkloadsService(s *Service) *OrganizationsLocationsWorkloadsService {
	rs := &OrganizationsLocationsWorkloadsService{s: s}
	rs.Updates = NewOrganizationsLocationsWorkloadsUpdatesService(s)
	rs.Violations = NewOrganizationsLocationsWorkloadsViolationsService(s)
	return rs
}

type OrganizationsLocationsWorkloadsService struct {
	s *Service

	Updates *OrganizationsLocationsWorkloadsUpdatesService

	Violations *OrganizationsLocationsWorkloadsViolationsService
}

func NewOrganizationsLocationsWorkloadsUpdatesService(s *Service) *OrganizationsLocationsWorkloadsUpdatesService {
	rs := &OrganizationsLocationsWorkloadsUpdatesService{s: s}
	return rs
}

type OrganizationsLocationsWorkloadsUpdatesService struct {
	s *Service
}

func NewOrganizationsLocationsWorkloadsViolationsService(s *Service) *OrganizationsLocationsWorkloadsViolationsService {
	rs := &OrganizationsLocationsWorkloadsViolationsService{s: s}
	return rs
}

type OrganizationsLocationsWorkloadsViolationsService struct {
	s *Service
}

// GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest: Request for
// acknowledging the violation
type GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest struct {
	// AcknowledgeType: Optional. Acknowledge type of specified violation.
	//
	// Possible values:
	//   "ACKNOWLEDGE_TYPE_UNSPECIFIED" - Acknowledge type unspecified.
	//   "SINGLE_VIOLATION" - Acknowledge only the specific violation.
	//   "EXISTING_CHILD_RESOURCE_VIOLATIONS" - Acknowledge specified orgPolicy
	// violation and also associated resource violations.
	AcknowledgeType string `json:"acknowledgeType,omitempty"`
	// Comment: Required. Business justification explaining the need for violation
	// acknowledgement
	Comment string `json:"comment,omitempty"`
	// NonCompliantOrgPolicy: Optional. This field is deprecated and will be
	// removed in future version of the API. Name of the OrgPolicy which was
	// modified with non-compliant change and resulted in this violation. Format:
	// projects/{project_number}/policies/{constraint_name}
	// folders/{folder_id}/policies/{constraint_name}
	// organizations/{organization_id}/policies/{constraint_name}
	NonCompliantOrgPolicy string `json:"nonCompliantOrgPolicy,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AcknowledgeType") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AcknowledgeType") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse: Response for
// violation acknowledgement
type GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse struct {
	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
}

// GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse: Response
// containing the analysis results for the hypothetical resource move.
type GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse struct {
	// AssetMoveAnalyses: List of analysis results for each asset in scope.
	AssetMoveAnalyses []*GoogleCloudAssuredworkloadsV1AssetMoveAnalysis `json:"assetMoveAnalyses,omitempty"`
	// NextPageToken: The next page token. Is empty if the last page is reached.
	NextPageToken string `json:"nextPageToken,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "AssetMoveAnalyses") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AssetMoveAnalyses") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateOperationMetadata: Operation
// metadata to give request details of ApplyWorkloadUpdate.
type GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateOperationMetadata struct {
	// Action: Optional. The time the operation was created.
	//
	// Possible values:
	//   "WORKLOAD_UPDATE_ACTION_UNSPECIFIED" - Unspecified value.
	//   "APPLY" - The update is applied.
	Action string `json:"action,omitempty"`
	// CreateTime: Optional. Output only. The time the operation was created.
	CreateTime string `json:"createTime,omitempty"`
	// UpdateName: Required. The resource name of the update
	UpdateName string `json:"updateName,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Action") to unconditionally
	// include in API requests. By default, fields with empty or default values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Action") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateOperationMetadata) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateOperationMetadata
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest: Request to apply
// update to a workload.
type GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest struct {
	// Action: The action to be performed on the update.
	//
	// Possible values:
	//   "WORKLOAD_UPDATE_ACTION_UNSPECIFIED" - Unspecified value.
	//   "APPLY" - The update is applied.
	Action string `json:"action,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Action") to unconditionally
	// include in API requests. By default, fields with empty or default values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Action") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse: Response for
// ApplyWorkloadUpdate endpoint.
type GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse struct {
	// AppliedUpdate: The update that was applied.
	AppliedUpdate *GoogleCloudAssuredworkloadsV1WorkloadUpdate `json:"appliedUpdate,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AppliedUpdate") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AppliedUpdate") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1AssetMoveAnalysis: Represents move analysis
// results for an asset.
type GoogleCloudAssuredworkloadsV1AssetMoveAnalysis struct {
	// AnalysisGroups: List of eligible analyses performed for the asset.
	AnalysisGroups []*GoogleCloudAssuredworkloadsV1MoveAnalysisGroup `json:"analysisGroups,omitempty"`
	// Asset: The full resource name of the asset being analyzed. Example:
	// //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instan
	// ce1
	Asset string `json:"asset,omitempty"`
	// AssetType: Type of the asset being analyzed. Possible values will be among
	// the ones listed here
	// (https://cloud.google.com/asset-inventory/docs/supported-asset-types).
	AssetType string `json:"assetType,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AnalysisGroups") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AnalysisGroups") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1AssetMoveAnalysis) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1AssetMoveAnalysis
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1CreateWorkloadOperationMetadata: Operation
// metadata to give request details of CreateWorkload.
type GoogleCloudAssuredworkloadsV1CreateWorkloadOperationMetadata struct {
	// ComplianceRegime: Optional. Compliance controls that should be applied to
	// the resources managed by the workload.
	//
	// Possible values:
	//   "COMPLIANCE_REGIME_UNSPECIFIED" - The default value. This value is used if
	// the control package is omitted or unknown.
	//   "ASSURED_WORKLOADS_FOR_PARTNERS" - Specifies a [Sovereign Controls by
	// Partners](https://cloud.google.com/sovereign-controls-by-partners/docs/overvi
	// ew) control package. To use this control package, you must also specify the
	// partner field from the list of Sovereign Controls by Partners.
	//   "AUSTRALIA_DATA_BOUNDARY_AND_SUPPORT" - Australia Data Boundary and
	// Support
	//   "CANADA_DATA_BOUNDARY_AND_SUPPORT" - Canada Data Boundary and Support
	//   "DATA_BOUNDARY_FOR_CANADA_CONTROLLED_GOODS" - Data Boundary for Canada
	// Controlled Goods
	//   "DATA_BOUNDARY_FOR_CANADA_PROTECTED_B" - Data Boundary for Canada
	// Protected B
	//   "DATA_BOUNDARY_FOR_CJIS" - Data Boundary for Criminal Justice Information
	// Systems (CJIS)
	//   "DATA_BOUNDARY_FOR_FEDRAMP_HIGH" - Data Boundary for FedRAMP High
	//   "DATA_BOUNDARY_FOR_FEDRAMP_MODERATE" - Data Boundary for FedRAMP Moderate
	//   "DATA_BOUNDARY_FOR_IL2" - Data Boundary for Impact Level 2 (IL2)
	//   "DATA_BOUNDARY_FOR_IL4" - Data Boundary for Impact Level 4 (IL4)
	//   "DATA_BOUNDARY_FOR_IL5" - Data Boundary for Impact Level 5 (IL5)
	//   "DATA_BOUNDARY_FOR_IRS_PUBLICATION_1075" - Data Boundary for IRS
	// Publication 1075
	//   "DATA_BOUNDARY_FOR_ITAR" - Data Boundary for International Traffic in Arms
	// Regulations (ITAR)
	//   "EU_DATA_BOUNDARY_AND_SUPPORT" - European Union (EU) Data Boundary and
	// Support
	//   "ISRAEL_DATA_BOUNDARY_AND_SUPPORT" - Israel Data Boundary and Support
	//   "JAPAN_DATA_BOUNDARY" - Japan Data Boundary
	//   "KSA_DATA_BOUNDARY_WITH_ACCESS_JUSTIFICATIONS" - Kingdom of Saudi Arabia
	// (KSA) Data Boundary with Access Justifications
	//   "REGIONAL_DATA_BOUNDARY" - Data boundary for one of Assured Workloads'
	// *Free tier* control packages. Determines the region by specifying the data
	// location during workload creation.
	//   "US_DATA_BOUNDARY_AND_SUPPORT" - United States (US) Data Boundary and
	// Support
	//   "US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES" - United States (US)
	// Data Boundary for Healthcare and Life Sciences
	//   "US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES_WITH_SUPPORT" - United
	// States (US) Data Boundary for Healthcare and Life Sciences with Support
	//   "AU_REGIONS_AND_US_SUPPORT" - Use the AUSTRALIA_DATA_BOUNDARY_AND_SUPPORT
	// enum for this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "CA_PROTECTED_B" - Use the DATA_BOUNDARY_FOR_CANADA_PROTECTED_B enum for
	// this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "CA_REGIONS_AND_SUPPORT" - Use the CANADA_DATA_BOUNDARY_AND_SUPPORT enum
	// for this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "CANADA_CONTROLLED_GOODS" - Use the
	// DATA_BOUNDARY_FOR_CANADA_CONTROLLED_GOODS enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "CJIS" - Use the DATA_BOUNDARY_FOR_CJIS enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "EU_REGIONS_AND_SUPPORT" - Use the EU_DATA_BOUNDARY_AND_SUPPORT enum for
	// this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "FEDRAMP_HIGH" - Use the DATA_BOUNDARY_FOR_FEDRAMP_HIGH enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "FEDRAMP_MODERATE" - Use the DATA_BOUNDARY_FOR_FEDRAMP_MODERATE enum for
	// this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "HEALTHCARE_AND_LIFE_SCIENCES_CONTROLS" - Use the
	// US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES enum for this control
	// package instead, as the name of the associated Assured Workloads control
	// package has changed.
	//   "HEALTHCARE_AND_LIFE_SCIENCES_CONTROLS_US_SUPPORT" - Use the
	// US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES_WITH_SUPPORT enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "HIPAA" - Deprecated: Consider using the Data Boundary for US Healthcare
	// and Life Sciences control package instead.
	//   "HITRUST" - Deprecated: Consider using the Data Boundary for US Healthcare
	// and Life Sciences control package instead.
	//   "IL2" - Use the DATA_BOUNDARY_FOR_IL2 enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "IL4" - Use the DATA_BOUNDARY_FOR_IL4 enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "IL5" - Use the DATA_BOUNDARY_FOR_IL5 enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "IRS_1075" - Use the DATA_BOUNDARY_FOR_IRS_PUBLICATION_1075 enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "ISR_REGIONS" - Use the ISRAEL_DATA_BOUNDARY_AND_SUPPORT enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "ISR_REGIONS_AND_SUPPORT" - Use the ISRAEL_DATA_BOUNDARY_AND_SUPPORT enum
	// for this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "ITAR" - Use the DATA_BOUNDARY_FOR_ITAR enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "JP_REGIONS_AND_SUPPORT" - Use the JAPAN_DATA_BOUNDARY enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "KSA_REGIONS_AND_SUPPORT_WITH_SOVEREIGNTY_CONTROLS" - Use the
	// KSA_DATA_BOUNDARY_WITH_ACCESS_JUSTIFICATIONS enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "REGIONAL_CONTROLS" - Use the REGIONAL_DATA_BOUNDARY enum for this control
	// package instead, as the name of the associated Assured Workloads control
	// package has changed.
	//   "US_REGIONAL_ACCESS" - Use the US_DATA_BOUNDARY_AND_SUPPORT enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	ComplianceRegime string `json:"complianceRegime,omitempty"`
	// CreateTime: Optional. Time when the operation was created.
	CreateTime string `json:"createTime,omitempty"`
	// DisplayName: Optional. The display name of the workload.
	DisplayName string `json:"displayName,omitempty"`
	// Parent: Optional. The parent of the workload.
	Parent string `json:"parent,omitempty"`
	// ForceSendFields is a list of field names (e.g. "ComplianceRegime") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "ComplianceRegime") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1CreateWorkloadOperationMetadata) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1CreateWorkloadOperationMetadata
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse: Response for
// EnableComplianceUpdates endpoint.
type GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse struct {
	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
}

// GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse: Response for
// EnableResourceMonitoring endpoint.
type GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse struct {
	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
}

// GoogleCloudAssuredworkloadsV1ListViolationsResponse: Response of
// ListViolations endpoint.
type GoogleCloudAssuredworkloadsV1ListViolationsResponse struct {
	// NextPageToken: The next page token. Returns empty if reached the last page.
	NextPageToken string `json:"nextPageToken,omitempty"`
	// Violations: List of Violations under a Workload.
	Violations []*GoogleCloudAssuredworkloadsV1Violation `json:"violations,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "NextPageToken") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "NextPageToken") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ListViolationsResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ListViolationsResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse: Response of
// listing the compliance updates per workload with pagination.
type GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse struct {
	// NextPageToken: The next page token. Return empty if reached the last page.
	NextPageToken string `json:"nextPageToken,omitempty"`
	// WorkloadUpdates: The list of workload updates for a given workload.
	WorkloadUpdates []*GoogleCloudAssuredworkloadsV1WorkloadUpdate `json:"workloadUpdates,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "NextPageToken") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "NextPageToken") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ListWorkloadsResponse: Response of
// ListWorkloads endpoint.
type GoogleCloudAssuredworkloadsV1ListWorkloadsResponse struct {
	// NextPageToken: The next page token. Return empty if reached the last page.
	NextPageToken string `json:"nextPageToken,omitempty"`
	// Workloads: List of Workloads under a given parent.
	Workloads []*GoogleCloudAssuredworkloadsV1Workload `json:"workloads,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "NextPageToken") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "NextPageToken") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ListWorkloadsResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ListWorkloadsResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1MoveAnalysisGroup: Represents a logical group
// of checks performed for an asset. If successful, the group contains the
// analysis result, otherwise it contains an error with the failure reason.
type GoogleCloudAssuredworkloadsV1MoveAnalysisGroup struct {
	// AnalysisResult: Result of a successful analysis.
	AnalysisResult *GoogleCloudAssuredworkloadsV1MoveAnalysisResult `json:"analysisResult,omitempty"`
	// DisplayName: Name of the analysis group.
	DisplayName string `json:"displayName,omitempty"`
	// Error: Error details for a failed analysis.
	Error *GoogleRpcStatus `json:"error,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AnalysisResult") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AnalysisResult") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1MoveAnalysisGroup) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1MoveAnalysisResult: Represents the successful
// move analysis results for a group.
type GoogleCloudAssuredworkloadsV1MoveAnalysisResult struct {
	// Blockers: List of blockers. If not resolved, these will result in compliance
	// violations in the target.
	Blockers []*GoogleCloudAssuredworkloadsV1MoveImpact `json:"blockers,omitempty"`
	// Warnings: List of warnings. These are risks that may or may not result in
	// compliance violations.
	Warnings []*GoogleCloudAssuredworkloadsV1MoveImpact `json:"warnings,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Blockers") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Blockers") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1MoveAnalysisResult) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1MoveAnalysisResult
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1MoveImpact: Represents the impact of moving the
// asset to the target.
type GoogleCloudAssuredworkloadsV1MoveImpact struct {
	// Detail: Explanation of the impact.
	Detail string `json:"detail,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Detail") to unconditionally
	// include in API requests. By default, fields with empty or default values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Detail") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1MoveImpact) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1MoveImpact
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest: Request for
// updating permission settings for a partner workload.
type GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest struct {
	// Etag: Optional. The etag of the workload. If this is provided, it must match
	// the server's etag.
	Etag string `json:"etag,omitempty"`
	// PartnerPermissions: Required. The partner permissions to be updated.
	PartnerPermissions *GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions `json:"partnerPermissions,omitempty"`
	// UpdateMask: Required. The list of fields to be updated. E.g. update_mask {
	// paths: "partner_permissions.data_logs_viewer"}
	UpdateMask string `json:"updateMask,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Etag") to unconditionally
	// include in API requests. By default, fields with empty or default values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Etag") to include in API requests
	// with the JSON null value. By default, fields with empty values are omitted
	// from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1OrgPolicy: This assured workload service object
// is used to represent the org policy attached to a resource. It servces the
// same purpose as the orgpolicy.v2.Policy object but with functionality that
// is limited to what is supported by Assured Workloads(e.g. only one rule
// under one OrgPolicy object, no conditions, etc).
type GoogleCloudAssuredworkloadsV1OrgPolicy struct {
	// Constraint: The constraint name of the OrgPolicy. e.g.
	// "constraints/gcp.resourceLocations".
	Constraint string `json:"constraint,omitempty"`
	// Inherit: If `inherit` is true, policy rules of the lowest ancestor in the
	// resource hierarchy chain are inherited. If it is false, policy rules are not
	// inherited.
	Inherit bool `json:"inherit,omitempty"`
	// Reset: Ignores policies set above this resource and restores to the
	// `constraint_default` value. `reset` can only be true when `rules` is empty
	// and `inherit` is false.
	Reset bool `json:"reset,omitempty"`
	// Resource: Resource that the OrgPolicy attaches to. Format: folders/123"
	// projects/123".
	Resource string `json:"resource,omitempty"`
	// Rule: The rule of the OrgPolicy.
	Rule *GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule `json:"rule,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Constraint") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Constraint") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1OrgPolicy) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1OrgPolicy
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule: A rule used to express
// this policy.
type GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule struct {
	// AllowAll: ListPolicy only when all values are allowed.
	AllowAll bool `json:"allowAll,omitempty"`
	// DenyAll: ListPolicy only when all values are denied.
	DenyAll bool `json:"denyAll,omitempty"`
	// Enforce: BooleanPolicy only.
	Enforce bool `json:"enforce,omitempty"`
	// Values: ListPolicy only when custom values are specified.
	Values *GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues `json:"values,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AllowAll") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AllowAll") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues: The values
// allowed for a ListPolicy.
type GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues struct {
	// AllowedValues: List of values allowed at this resource.
	AllowedValues []string `json:"allowedValues,omitempty"`
	// DeniedValues: List of values denied at this resource.
	DeniedValues []string `json:"deniedValues,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AllowedValues") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AllowedValues") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1OrgPolicyUpdate: Represents an update for an
// org policy control applied on an Assured Workload resource. The inherited
// org policy is not considered.
type GoogleCloudAssuredworkloadsV1OrgPolicyUpdate struct {
	// AppliedPolicy: The org policy currently applied on the assured workload
	// resource.
	AppliedPolicy *GoogleCloudAssuredworkloadsV1OrgPolicy `json:"appliedPolicy,omitempty"`
	// SuggestedPolicy: The suggested org policy that replaces the applied policy.
	SuggestedPolicy *GoogleCloudAssuredworkloadsV1OrgPolicy `json:"suggestedPolicy,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AppliedPolicy") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AppliedPolicy") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1OrgPolicyUpdate) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest: Request for
// restricting list of available resources in Workload environment.
type GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest struct {
	// RestrictionType: Required. The type of restriction for using gcp products in
	// the Workload environment.
	//
	// Possible values:
	//   "RESTRICTION_TYPE_UNSPECIFIED" - Unknown restriction type.
	//   "ALLOW_ALL_GCP_RESOURCES" - Allow the use all of all gcp products,
	// irrespective of the compliance posture. This effectively removes
	// gcp.restrictServiceUsage OrgPolicy on the AssuredWorkloads Folder.
	//   "ALLOW_COMPLIANT_RESOURCES" - Based on Workload's compliance regime,
	// allowed list changes. See -
	// https://cloud.google.com/assured-workloads/docs/supported-products for the
	// list of supported resources.
	//   "APPEND_COMPLIANT_RESOURCES" - Similar to ALLOW_COMPLIANT_RESOURCES but
	// adds the list of compliant resources to the existing list of compliant
	// resources. Effective org-policy of the Folder is considered to ensure there
	// is no disruption to the existing customer workflows.
	RestrictionType string `json:"restrictionType,omitempty"`
	// ForceSendFields is a list of field names (e.g. "RestrictionType") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "RestrictionType") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse: Response for
// restricting the list of allowed resources.
type GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse struct {
	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
}

// GoogleCloudAssuredworkloadsV1UpdateDetails: The details of the update.
type GoogleCloudAssuredworkloadsV1UpdateDetails struct {
	// OrgPolicyUpdate: Update to one org policy, e.g. gcp.resourceLocation.
	OrgPolicyUpdate *GoogleCloudAssuredworkloadsV1OrgPolicyUpdate `json:"orgPolicyUpdate,omitempty"`
	// ForceSendFields is a list of field names (e.g. "OrgPolicyUpdate") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "OrgPolicyUpdate") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1UpdateDetails) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1UpdateDetails
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1Violation: Workload monitoring Violation.
type GoogleCloudAssuredworkloadsV1Violation struct {
	// Acknowledged: A boolean that indicates if the violation is acknowledged
	Acknowledged bool `json:"acknowledged,omitempty"`
	// AcknowledgementTime: Optional. Timestamp when this violation was
	// acknowledged first. Check exception_contexts to find the last time the
	// violation was acknowledged when there are more than one violations. This
	// field will be absent when acknowledged field is marked as false.
	AcknowledgementTime string `json:"acknowledgementTime,omitempty"`
	// AssociatedOrgPolicyViolationId: Optional. Output only. Violation Id of the
	// org-policy violation due to which the resource violation is caused. Empty
	// for org-policy violations.
	AssociatedOrgPolicyViolationId string `json:"associatedOrgPolicyViolationId,omitempty"`
	// AuditLogLink: Output only. Immutable. Audit Log Link for violated resource
	// Format:
	// https://console.cloud.google.com/logs/query;query={logName}{protoPayload.resourceName}{timeRange}{folder}
	AuditLogLink string `json:"auditLogLink,omitempty"`
	// BeginTime: Output only. Time of the event which triggered the Violation.
	BeginTime string `json:"beginTime,omitempty"`
	// Category: Output only. Category under which this violation is mapped. e.g.
	// Location, Service Usage, Access, Encryption, etc.
	Category string `json:"category,omitempty"`
	// Description: Output only. Description for the Violation. e.g. OrgPolicy
	// gcp.resourceLocations has non compliant value.
	Description string `json:"description,omitempty"`
	// ExceptionAuditLogLink: Output only. Immutable. Audit Log link to find
	// business justification provided for violation exception. Format:
	// https://console.cloud.google.com/logs/query;query={logName}{protoPayload.resourceName}{protoPayload.methodName}{timeRange}{organization}
	ExceptionAuditLogLink string `json:"exceptionAuditLogLink,omitempty"`
	// ExceptionContexts: Output only. List of all the exception detail added for
	// the violation.
	ExceptionContexts []*GoogleCloudAssuredworkloadsV1ViolationExceptionContext `json:"exceptionContexts,omitempty"`
	// Name: Output only. Immutable. Name of the Violation. Format:
	// organizations/{organization}/locations/{location}/workloads/{workload_id}/vio
	// lations/{violations_id}
	Name string `json:"name,omitempty"`
	// NonCompliantOrgPolicy: Output only. Immutable. Name of the OrgPolicy which
	// was modified with non-compliant change and resulted this violation. Format:
	// projects/{project_number}/policies/{constraint_name}
	// folders/{folder_id}/policies/{constraint_name}
	// organizations/{organization_id}/policies/{constraint_name}
	NonCompliantOrgPolicy string `json:"nonCompliantOrgPolicy,omitempty"`
	// OrgPolicyConstraint: Output only. Immutable. The org-policy-constraint that
	// was incorrectly changed, which resulted in this violation.
	OrgPolicyConstraint string `json:"orgPolicyConstraint,omitempty"`
	// ParentProjectNumber: Optional. Output only. Parent project number where
	// resource is present. Empty for org-policy violations.
	ParentProjectNumber string `json:"parentProjectNumber,omitempty"`
	// Remediation: Output only. Compliance violation remediation
	Remediation *GoogleCloudAssuredworkloadsV1ViolationRemediation `json:"remediation,omitempty"`
	// ResolveTime: Output only. Time of the event which fixed the Violation. If
	// the violation is ACTIVE this will be empty.
	ResolveTime string `json:"resolveTime,omitempty"`
	// ResourceName: Optional. Output only. Name of the resource like
	// //storage.googleapis.com/myprojectxyz-testbucket. Empty for org-policy
	// violations.
	ResourceName string `json:"resourceName,omitempty"`
	// ResourceType: Optional. Output only. Type of the resource like
	// compute.googleapis.com/Disk, etc. Empty for org-policy violations.
	ResourceType string `json:"resourceType,omitempty"`
	// State: Output only. State of the violation
	//
	// Possible values:
	//   "STATE_UNSPECIFIED" - Unspecified state.
	//   "RESOLVED" - Violation is resolved.
	//   "UNRESOLVED" - Violation is Unresolved
	//   "EXCEPTION" - Violation is Exception
	State string `json:"state,omitempty"`
	// UpdateTime: Output only. The last time when the Violation record was
	// updated.
	UpdateTime string `json:"updateTime,omitempty"`
	// ViolationType: Output only. Type of the violation
	//
	// Possible values:
	//   "VIOLATION_TYPE_UNSPECIFIED" - Unspecified type.
	//   "ORG_POLICY" - Org Policy Violation.
	//   "RESOURCE" - Resource Violation.
	ViolationType string `json:"violationType,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "Acknowledged") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Acknowledged") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1Violation) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1Violation
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ViolationExceptionContext: Violation exception
// detail.
type GoogleCloudAssuredworkloadsV1ViolationExceptionContext struct {
	// AcknowledgementTime: Timestamp when the violation was acknowledged.
	AcknowledgementTime string `json:"acknowledgementTime,omitempty"`
	// Comment: Business justification provided towards the acknowledgement of the
	// violation.
	Comment string `json:"comment,omitempty"`
	// UserName: Name of the user (or service account) who acknowledged the
	// violation.
	UserName string `json:"userName,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AcknowledgementTime") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AcknowledgementTime") to include
	// in API requests with the JSON null value. By default, fields with empty
	// values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ViolationExceptionContext) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ViolationExceptionContext
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ViolationRemediation: Represents remediation
// guidance to resolve compliance violation for AssuredWorkload
type GoogleCloudAssuredworkloadsV1ViolationRemediation struct {
	// CompliantValues: Values that can resolve the violation For example: for list
	// org policy violations, this will either be the list of allowed or denied
	// values
	CompliantValues []string `json:"compliantValues,omitempty"`
	// Instructions: Required. Remediation instructions to resolve violations
	Instructions *GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions `json:"instructions,omitempty"`
	// RemediationType: Output only. Reemediation type based on the type of org
	// policy values violated
	//
	// Possible values:
	//   "REMEDIATION_TYPE_UNSPECIFIED" - Unspecified remediation type
	//   "REMEDIATION_BOOLEAN_ORG_POLICY_VIOLATION" - Remediation type for boolean
	// org policy
	//   "REMEDIATION_LIST_ALLOWED_VALUES_ORG_POLICY_VIOLATION" - Remediation type
	// for list org policy which have allowed values in the monitoring rule
	//   "REMEDIATION_LIST_DENIED_VALUES_ORG_POLICY_VIOLATION" - Remediation type
	// for list org policy which have denied values in the monitoring rule
	//   "REMEDIATION_RESTRICT_CMEK_CRYPTO_KEY_PROJECTS_ORG_POLICY_VIOLATION" -
	// Remediation type for gcp.restrictCmekCryptoKeyProjects
	//   "REMEDIATION_RESOURCE_VIOLATION" - Remediation type for resource
	// violation.
	//   "REMEDIATION_RESOURCE_VIOLATION_NON_CMEK_SERVICES" - Remediation type for
	// resource violation due to gcp.restrictNonCmekServices
	RemediationType string `json:"remediationType,omitempty"`
	// ForceSendFields is a list of field names (e.g. "CompliantValues") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "CompliantValues") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ViolationRemediation) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ViolationRemediation
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions: Instructions
// to remediate violation
type GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions struct {
	// ConsoleInstructions: Remediation instructions to resolve violation via cloud
	// console
	ConsoleInstructions *GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole `json:"consoleInstructions,omitempty"`
	// GcloudInstructions: Remediation instructions to resolve violation via gcloud
	// cli
	GcloudInstructions *GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud `json:"gcloudInstructions,omitempty"`
	// ForceSendFields is a list of field names (e.g. "ConsoleInstructions") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "ConsoleInstructions") to include
	// in API requests with the JSON null value. By default, fields with empty
	// values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole:
// Remediation instructions to resolve violation via cloud console
type GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole struct {
	// AdditionalLinks: Additional urls for more information about steps
	AdditionalLinks []string `json:"additionalLinks,omitempty"`
	// ConsoleUris: Link to console page where violations can be resolved
	ConsoleUris []string `json:"consoleUris,omitempty"`
	// Steps: Steps to resolve violation via cloud console
	Steps []string `json:"steps,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AdditionalLinks") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AdditionalLinks") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud:
// Remediation instructions to resolve violation via gcloud cli
type GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud struct {
	// AdditionalLinks: Additional urls for more information about steps
	AdditionalLinks []string `json:"additionalLinks,omitempty"`
	// GcloudCommands: Gcloud command to resolve violation
	GcloudCommands []string `json:"gcloudCommands,omitempty"`
	// Steps: Steps to resolve violation via gcloud cli
	Steps []string `json:"steps,omitempty"`
	// ForceSendFields is a list of field names (e.g. "AdditionalLinks") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "AdditionalLinks") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1Workload: A Workload object for managing highly
// regulated workloads of cloud customers.
type GoogleCloudAssuredworkloadsV1Workload struct {
	// BillingAccount: Optional. The billing account used for the resources which
	// are direct children of workload. This billing account is initially
	// associated with the resources created as part of Workload creation. After
	// the initial creation of these resources, the customer can change the
	// assigned billing account. The resource name has the form
	// `billingAccounts/{billing_account_id}`. For example,
	// `billingAccounts/012345-567890-ABCDEF`.
	BillingAccount string `json:"billingAccount,omitempty"`
	// ComplianceRegime: Required. Immutable. Compliance Regime associated with
	// this workload.
	//
	// Possible values:
	//   "COMPLIANCE_REGIME_UNSPECIFIED" - The default value. This value is used if
	// the control package is omitted or unknown.
	//   "ASSURED_WORKLOADS_FOR_PARTNERS" - Specifies a [Sovereign Controls by
	// Partners](https://cloud.google.com/sovereign-controls-by-partners/docs/overvi
	// ew) control package. To use this control package, you must also specify the
	// partner field from the list of Sovereign Controls by Partners.
	//   "AUSTRALIA_DATA_BOUNDARY_AND_SUPPORT" - Australia Data Boundary and
	// Support
	//   "CANADA_DATA_BOUNDARY_AND_SUPPORT" - Canada Data Boundary and Support
	//   "DATA_BOUNDARY_FOR_CANADA_CONTROLLED_GOODS" - Data Boundary for Canada
	// Controlled Goods
	//   "DATA_BOUNDARY_FOR_CANADA_PROTECTED_B" - Data Boundary for Canada
	// Protected B
	//   "DATA_BOUNDARY_FOR_CJIS" - Data Boundary for Criminal Justice Information
	// Systems (CJIS)
	//   "DATA_BOUNDARY_FOR_FEDRAMP_HIGH" - Data Boundary for FedRAMP High
	//   "DATA_BOUNDARY_FOR_FEDRAMP_MODERATE" - Data Boundary for FedRAMP Moderate
	//   "DATA_BOUNDARY_FOR_IL2" - Data Boundary for Impact Level 2 (IL2)
	//   "DATA_BOUNDARY_FOR_IL4" - Data Boundary for Impact Level 4 (IL4)
	//   "DATA_BOUNDARY_FOR_IL5" - Data Boundary for Impact Level 5 (IL5)
	//   "DATA_BOUNDARY_FOR_IRS_PUBLICATION_1075" - Data Boundary for IRS
	// Publication 1075
	//   "DATA_BOUNDARY_FOR_ITAR" - Data Boundary for International Traffic in Arms
	// Regulations (ITAR)
	//   "EU_DATA_BOUNDARY_AND_SUPPORT" - European Union (EU) Data Boundary and
	// Support
	//   "ISRAEL_DATA_BOUNDARY_AND_SUPPORT" - Israel Data Boundary and Support
	//   "JAPAN_DATA_BOUNDARY" - Japan Data Boundary
	//   "KSA_DATA_BOUNDARY_WITH_ACCESS_JUSTIFICATIONS" - Kingdom of Saudi Arabia
	// (KSA) Data Boundary with Access Justifications
	//   "REGIONAL_DATA_BOUNDARY" - Data boundary for one of Assured Workloads'
	// *Free tier* control packages. Determines the region by specifying the data
	// location during workload creation.
	//   "US_DATA_BOUNDARY_AND_SUPPORT" - United States (US) Data Boundary and
	// Support
	//   "US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES" - United States (US)
	// Data Boundary for Healthcare and Life Sciences
	//   "US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES_WITH_SUPPORT" - United
	// States (US) Data Boundary for Healthcare and Life Sciences with Support
	//   "AU_REGIONS_AND_US_SUPPORT" - Use the AUSTRALIA_DATA_BOUNDARY_AND_SUPPORT
	// enum for this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "CA_PROTECTED_B" - Use the DATA_BOUNDARY_FOR_CANADA_PROTECTED_B enum for
	// this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "CA_REGIONS_AND_SUPPORT" - Use the CANADA_DATA_BOUNDARY_AND_SUPPORT enum
	// for this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "CANADA_CONTROLLED_GOODS" - Use the
	// DATA_BOUNDARY_FOR_CANADA_CONTROLLED_GOODS enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "CJIS" - Use the DATA_BOUNDARY_FOR_CJIS enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "EU_REGIONS_AND_SUPPORT" - Use the EU_DATA_BOUNDARY_AND_SUPPORT enum for
	// this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "FEDRAMP_HIGH" - Use the DATA_BOUNDARY_FOR_FEDRAMP_HIGH enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "FEDRAMP_MODERATE" - Use the DATA_BOUNDARY_FOR_FEDRAMP_MODERATE enum for
	// this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "HEALTHCARE_AND_LIFE_SCIENCES_CONTROLS" - Use the
	// US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES enum for this control
	// package instead, as the name of the associated Assured Workloads control
	// package has changed.
	//   "HEALTHCARE_AND_LIFE_SCIENCES_CONTROLS_US_SUPPORT" - Use the
	// US_DATA_BOUNDARY_FOR_HEALTHCARE_AND_LIFE_SCIENCES_WITH_SUPPORT enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "HIPAA" - Deprecated: Consider using the Data Boundary for US Healthcare
	// and Life Sciences control package instead.
	//   "HITRUST" - Deprecated: Consider using the Data Boundary for US Healthcare
	// and Life Sciences control package instead.
	//   "IL2" - Use the DATA_BOUNDARY_FOR_IL2 enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "IL4" - Use the DATA_BOUNDARY_FOR_IL4 enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "IL5" - Use the DATA_BOUNDARY_FOR_IL5 enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "IRS_1075" - Use the DATA_BOUNDARY_FOR_IRS_PUBLICATION_1075 enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "ISR_REGIONS" - Use the ISRAEL_DATA_BOUNDARY_AND_SUPPORT enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "ISR_REGIONS_AND_SUPPORT" - Use the ISRAEL_DATA_BOUNDARY_AND_SUPPORT enum
	// for this control package instead, as the name of the associated Assured
	// Workloads control package has changed.
	//   "ITAR" - Use the DATA_BOUNDARY_FOR_ITAR enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "JP_REGIONS_AND_SUPPORT" - Use the JAPAN_DATA_BOUNDARY enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	//   "KSA_REGIONS_AND_SUPPORT_WITH_SOVEREIGNTY_CONTROLS" - Use the
	// KSA_DATA_BOUNDARY_WITH_ACCESS_JUSTIFICATIONS enum for this control package
	// instead, as the name of the associated Assured Workloads control package has
	// changed.
	//   "REGIONAL_CONTROLS" - Use the REGIONAL_DATA_BOUNDARY enum for this control
	// package instead, as the name of the associated Assured Workloads control
	// package has changed.
	//   "US_REGIONAL_ACCESS" - Use the US_DATA_BOUNDARY_AND_SUPPORT enum for this
	// control package instead, as the name of the associated Assured Workloads
	// control package has changed.
	ComplianceRegime string `json:"complianceRegime,omitempty"`
	// ComplianceStatus: Output only. Count of active Violations in the Workload.
	ComplianceStatus *GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus `json:"complianceStatus,omitempty"`
	// CompliantButDisallowedServices: Output only. Urls for services which are
	// compliant for this Assured Workload, but which are currently disallowed by
	// the ResourceUsageRestriction org policy. Invoke RestrictAllowedResources
	// endpoint to allow your project developers to use these services in their
	// environment.
	CompliantButDisallowedServices []string `json:"compliantButDisallowedServices,omitempty"`
	// CreateTime: Output only. Immutable. The Workload creation timestamp.
	CreateTime string `json:"createTime,omitempty"`
	// DisplayName: Required. The user-assigned display name of the Workload. When
	// present it must be between 4 to 30 characters. Allowed characters are:
	// lowercase and uppercase letters, numbers, hyphen, and spaces. Example: My
	// Workload
	DisplayName string `json:"displayName,omitempty"`
	// EkmProvisioningResponse: Output only. Represents the Ekm Provisioning State
	// of the given workload.
	EkmProvisioningResponse *GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse `json:"ekmProvisioningResponse,omitempty"`
	// EnableSovereignControls: Optional. Indicates the sovereignty status of the
	// given workload. Currently meant to be used by Europe/Canada customers.
	EnableSovereignControls bool `json:"enableSovereignControls,omitempty"`
	// Etag: Optional. ETag of the workload, it is calculated on the basis of the
	// Workload contents. It will be used in Update & Delete operations.
	Etag string `json:"etag,omitempty"`
	// KajEnrollmentState: Output only. Represents the KAJ enrollment state of the
	// given workload.
	//
	// Possible values:
	//   "KAJ_ENROLLMENT_STATE_UNSPECIFIED" - Default State for KAJ Enrollment.
	//   "KAJ_ENROLLMENT_STATE_PENDING" - Pending State for KAJ Enrollment.
	//   "KAJ_ENROLLMENT_STATE_COMPLETE" - Complete State for KAJ Enrollment.
	KajEnrollmentState string `json:"kajEnrollmentState,omitempty"`
	// KmsSettings: Input only. Settings used to create a CMEK crypto key. When
	// set, a project with a KMS CMEK key is provisioned. This field is deprecated
	// as of Feb 28, 2022. In order to create a Keyring, callers should specify,
	// ENCRYPTION_KEYS_PROJECT or KEYRING in ResourceSettings.resource_type field.
	KmsSettings *GoogleCloudAssuredworkloadsV1WorkloadKMSSettings `json:"kmsSettings,omitempty"`
	// Labels: Optional. Labels applied to the workload.
	Labels map[string]string `json:"labels,omitempty"`
	// Name: Optional. The resource name of the workload. Format:
	// organizations/{organization}/locations/{location}/workloads/{workload}
	// Read-only.
	Name string `json:"name,omitempty"`
	// Partner: Optional. Partner regime associated with this workload.
	//
	// Possible values:
	//   "PARTNER_UNSPECIFIED"
	//   "LOCAL_CONTROLS_BY_S3NS" - Enum representing S3NS (Thales) partner.
	//   "SOVEREIGN_CONTROLS_BY_T_SYSTEMS" - Enum representing T_SYSTEM (TSI)
	// partner.
	//   "SOVEREIGN_CONTROLS_BY_SIA_MINSAIT" - Enum representing SIA_MINSAIT
	// (Indra) partner.
	//   "SOVEREIGN_CONTROLS_BY_PSN" - Enum representing PSN (TIM) partner.
	//   "SOVEREIGN_CONTROLS_BY_CNTXT" - Enum representing CNTXT (Kingdom of Saudi
	// Arabia) partner.
	//   "SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM" - Enum representing CNTXT (Kingdom of
	// Saudi Arabia) partner offering without EKM.
	//   "SPAIN_DATA_BOUNDARY_BY_TELEFONICA" - Enum representing Telefonica (Spain)
	// partner.
	Partner string `json:"partner,omitempty"`
	// PartnerPermissions: Optional. Permissions granted to the AW Partner SA
	// account for the customer workload
	PartnerPermissions *GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions `json:"partnerPermissions,omitempty"`
	// PartnerServicesBillingAccount: Optional. Billing account necessary for
	// purchasing services from Sovereign Partners. This field is required for
	// creating SIA/PSN/CNTXT/Telefonica partner workloads. The caller should have
	// 'billing.resourceAssociations.create' IAM permission on this
	// billing-account. The format of this string is
	// billingAccounts/AAAAAA-BBBBBB-CCCCCC
	PartnerServicesBillingAccount string `json:"partnerServicesBillingAccount,omitempty"`
	// ProvisionedResourcesParent: Input only. The parent resource for the
	// resources managed by this Assured Workload. May be either empty or a folder
	// resource which is a child of the Workload parent. If not specified all
	// resources are created under the parent organization. Format:
	// folders/{folder_id}
	ProvisionedResourcesParent string `json:"provisionedResourcesParent,omitempty"`
	// ResourceMonitoringEnabled: Output only. Indicates whether resource
	// monitoring is enabled for workload or not. It is true when Resource feed is
	// subscribed to AWM topic and AWM Service Agent Role is binded to AW Service
	// Account for resource Assured workload.
	ResourceMonitoringEnabled bool `json:"resourceMonitoringEnabled,omitempty"`
	// ResourceSettings: Input only. Resource properties that are used to customize
	// workload resources. These properties (such as custom project id) will be
	// used to create workload resources if possible. This field is optional.
	ResourceSettings []*GoogleCloudAssuredworkloadsV1WorkloadResourceSettings `json:"resourceSettings,omitempty"`
	// Resources: Output only. The resources associated with this workload. These
	// resources will be created when creating the workload. If any of the projects
	// already exist, the workload creation will fail. Always read only.
	Resources []*GoogleCloudAssuredworkloadsV1WorkloadResourceInfo `json:"resources,omitempty"`
	// SaaEnrollmentResponse: Output only. Represents the SAA enrollment response
	// of the given workload. SAA enrollment response is queried during GetWorkload
	// call. In failure cases, user friendly error message is shown in SAA details
	// page.
	SaaEnrollmentResponse *GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse `json:"saaEnrollmentResponse,omitempty"`
	// ViolationNotificationsEnabled: Optional. Indicates whether the e-mail
	// notification for a violation is enabled for a workload. This value will be
	// by default True, and if not present will be considered as true. This should
	// only be updated via updateWorkload call. Any Changes to this field during
	// the createWorkload call will not be honored. This will always be true while
	// creating the workload.
	ViolationNotificationsEnabled bool `json:"violationNotificationsEnabled,omitempty"`
	// WorkloadOptions: Optional. Options to be set for the given created workload.
	WorkloadOptions *GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions `json:"workloadOptions,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "BillingAccount") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "BillingAccount") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1Workload) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1Workload
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus: Represents the
// Compliance Status of this workload
type GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus struct {
	// AcknowledgedResourceViolationCount: Number of current resource violations
	// which are not acknowledged.
	AcknowledgedResourceViolationCount int64 `json:"acknowledgedResourceViolationCount,omitempty"`
	// AcknowledgedViolationCount: Number of current orgPolicy violations which are
	// acknowledged.
	AcknowledgedViolationCount int64 `json:"acknowledgedViolationCount,omitempty"`
	// ActiveResourceViolationCount: Number of current resource violations which
	// are acknowledged.
	ActiveResourceViolationCount int64 `json:"activeResourceViolationCount,omitempty"`
	// ActiveViolationCount: Number of current orgPolicy violations which are not
	// acknowledged.
	ActiveViolationCount int64 `json:"activeViolationCount,omitempty"`
	// ForceSendFields is a list of field names (e.g.
	// "AcknowledgedResourceViolationCount") to unconditionally include in API
	// requests. By default, fields with empty or default values are omitted from
	// API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g.
	// "AcknowledgedResourceViolationCount") to include in API requests with the
	// JSON null value. By default, fields with empty values are omitted from API
	// requests. See https://pkg.go.dev/google.golang.org/api#hdr-NullFields for
	// more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse: External key
// management systems(EKM) Provisioning response
type GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse struct {
	// EkmProvisioningErrorDomain: Indicates Ekm provisioning error if any.
	//
	// Possible values:
	//   "EKM_PROVISIONING_ERROR_DOMAIN_UNSPECIFIED" - No error domain
	//   "UNSPECIFIED_ERROR" - Error but domain is unspecified.
	//   "GOOGLE_SERVER_ERROR" - Internal logic breaks within provisioning code.
	//   "EXTERNAL_USER_ERROR" - Error occurred with the customer not granting
	// permission/creating resource.
	//   "EXTERNAL_PARTNER_ERROR" - Error occurred within the partner's
	// provisioning cluster.
	//   "TIMEOUT_ERROR" - Resource wasn't provisioned in the required 7 day time
	// period
	EkmProvisioningErrorDomain string `json:"ekmProvisioningErrorDomain,omitempty"`
	// EkmProvisioningErrorMapping: Detailed error message if Ekm provisioning
	// fails
	//
	// Possible values:
	//   "EKM_PROVISIONING_ERROR_MAPPING_UNSPECIFIED" - Error is unspecified.
	//   "INVALID_SERVICE_ACCOUNT" - Service account is used is invalid.
	//   "MISSING_METRICS_SCOPE_ADMIN_PERMISSION" - Iam permission
	// monitoring.MetricsScopeAdmin wasn't applied.
	//   "MISSING_EKM_CONNECTION_ADMIN_PERMISSION" - Iam permission
	// cloudkms.ekmConnectionsAdmin wasn't applied.
	EkmProvisioningErrorMapping string `json:"ekmProvisioningErrorMapping,omitempty"`
	// EkmProvisioningState: Output only. Indicates Ekm enrollment Provisioning of
	// a given workload.
	//
	// Possible values:
	//   "EKM_PROVISIONING_STATE_UNSPECIFIED" - Default State for Ekm Provisioning
	//   "EKM_PROVISIONING_STATE_PENDING" - Pending State for Ekm Provisioning
	//   "EKM_PROVISIONING_STATE_FAILED" - Failed State for Ekm Provisioning
	//   "EKM_PROVISIONING_STATE_COMPLETED" - Completed State for Ekm Provisioning
	EkmProvisioningState string `json:"ekmProvisioningState,omitempty"`
	// ForceSendFields is a list of field names (e.g. "EkmProvisioningErrorDomain")
	// to unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "EkmProvisioningErrorDomain") to
	// include in API requests with the JSON null value. By default, fields with
	// empty values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadKMSSettings: Settings specific to the
// Key Management Service.
type GoogleCloudAssuredworkloadsV1WorkloadKMSSettings struct {
	// NextRotationTime: Required. Input only. Immutable. The time at which the Key
	// Management Service will automatically create a new version of the crypto key
	// and mark it as the primary.
	NextRotationTime string `json:"nextRotationTime,omitempty"`
	// RotationPeriod: Required. Input only. Immutable. [next_rotation_time] will
	// be advanced by this period when the Key Management Service automatically
	// rotates a key. Must be at least 24 hours and at most 876,000 hours.
	RotationPeriod string `json:"rotationPeriod,omitempty"`
	// ForceSendFields is a list of field names (e.g. "NextRotationTime") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "NextRotationTime") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadKMSSettings) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadKMSSettings
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions: Permissions granted
// to the AW Partner SA account for the customer workload
type GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions struct {
	// AccessTransparencyLogsSupportCaseViewer: Optional. Allow partner to view
	// support case details for an AXT log
	AccessTransparencyLogsSupportCaseViewer bool `json:"accessTransparencyLogsSupportCaseViewer,omitempty"`
	// AssuredWorkloadsMonitoring: Optional. Allow partner to view violation
	// alerts.
	AssuredWorkloadsMonitoring bool `json:"assuredWorkloadsMonitoring,omitempty"`
	// DataLogsViewer: Optional. Allow the partner to view inspectability logs and
	// monitoring violations.
	DataLogsViewer bool `json:"dataLogsViewer,omitempty"`
	// ServiceAccessApprover: Optional. Allow partner to view access approval logs.
	ServiceAccessApprover bool `json:"serviceAccessApprover,omitempty"`
	// ForceSendFields is a list of field names (e.g.
	// "AccessTransparencyLogsSupportCaseViewer") to unconditionally include in API
	// requests. By default, fields with empty or default values are omitted from
	// API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g.
	// "AccessTransparencyLogsSupportCaseViewer") to include in API requests with
	// the JSON null value. By default, fields with empty values are omitted from
	// API requests. See https://pkg.go.dev/google.golang.org/api#hdr-NullFields
	// for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadResourceInfo: Represent the resources
// that are children of this Workload.
type GoogleCloudAssuredworkloadsV1WorkloadResourceInfo struct {
	// ResourceId: Output only. Resource identifier. For a project this represents
	// project_number.
	ResourceId int64 `json:"resourceId,omitempty,string"`
	// ResourceType: Indicates the type of resource.
	//
	// Possible values:
	//   "RESOURCE_TYPE_UNSPECIFIED" - Unknown resource type.
	//   "CONSUMER_PROJECT" - Deprecated. Existing workloads will continue to
	// support this, but new CreateWorkloadRequests should not specify this as an
	// input value.
	//   "CONSUMER_FOLDER" - Consumer Folder.
	//   "ENCRYPTION_KEYS_PROJECT" - Consumer project containing encryption keys.
	//   "KEYRING" - Keyring resource that hosts encryption keys.
	ResourceType string `json:"resourceType,omitempty"`
	// ForceSendFields is a list of field names (e.g. "ResourceId") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "ResourceId") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadResourceInfo) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadResourceInfo
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadResourceSettings: Represent the custom
// settings for the resources to be created.
type GoogleCloudAssuredworkloadsV1WorkloadResourceSettings struct {
	// DisplayName: User-assigned resource display name. If not empty it will be
	// used to create a resource with the specified name.
	DisplayName string `json:"displayName,omitempty"`
	// ResourceId: Resource identifier. For a project this represents project_id.
	// If the project is already taken, the workload creation will fail. For
	// KeyRing, this represents the keyring_id. For a folder, don't set this value
	// as folder_id is assigned by Google.
	ResourceId string `json:"resourceId,omitempty"`
	// ResourceType: Indicates the type of resource. This field should be specified
	// to correspond the id to the right project type (CONSUMER_PROJECT or
	// ENCRYPTION_KEYS_PROJECT)
	//
	// Possible values:
	//   "RESOURCE_TYPE_UNSPECIFIED" - Unknown resource type.
	//   "CONSUMER_PROJECT" - Deprecated. Existing workloads will continue to
	// support this, but new CreateWorkloadRequests should not specify this as an
	// input value.
	//   "CONSUMER_FOLDER" - Consumer Folder.
	//   "ENCRYPTION_KEYS_PROJECT" - Consumer project containing encryption keys.
	//   "KEYRING" - Keyring resource that hosts encryption keys.
	ResourceType string `json:"resourceType,omitempty"`
	// ForceSendFields is a list of field names (e.g. "DisplayName") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "DisplayName") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadResourceSettings) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadResourceSettings
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse: Signed Access
// Approvals (SAA) enrollment response.
type GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse struct {
	// SetupErrors: Indicates SAA enrollment setup error if any.
	//
	// Possible values:
	//   "SETUP_ERROR_UNSPECIFIED" - Unspecified.
	//   "ERROR_INVALID_BASE_SETUP" - Invalid states for all customers, to be
	// redirected to AA UI for additional details.
	//   "ERROR_MISSING_EXTERNAL_SIGNING_KEY" - Returned when there is not an EKM
	// key configured.
	//   "ERROR_NOT_ALL_SERVICES_ENROLLED" - Returned when there are no enrolled
	// services or the customer is enrolled in CAA only for a subset of services.
	//   "ERROR_SETUP_CHECK_FAILED" - Returned when exception was encountered
	// during evaluation of other criteria.
	SetupErrors []string `json:"setupErrors,omitempty"`
	// SetupStatus: Output only. Indicates SAA enrollment status of a given
	// workload.
	//
	// Possible values:
	//   "SETUP_STATE_UNSPECIFIED" - Unspecified.
	//   "STATUS_PENDING" - SAA enrollment pending.
	//   "STATUS_COMPLETE" - SAA enrollment comopleted.
	SetupStatus string `json:"setupStatus,omitempty"`
	// ForceSendFields is a list of field names (e.g. "SetupErrors") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "SetupErrors") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadUpdate: A workload update is a change
// to the workload's compliance configuration.
type GoogleCloudAssuredworkloadsV1WorkloadUpdate struct {
	// CreateTime: The time the update was created.
	CreateTime string `json:"createTime,omitempty"`
	// Details: The details of the update.
	Details *GoogleCloudAssuredworkloadsV1UpdateDetails `json:"details,omitempty"`
	// Name: Output only. Immutable. Identifier. Resource name of the
	// WorkloadUpdate. Format:
	// organizations/{organization}/locations/{location}/workloads/{workload}/update
	// s/{update}
	Name string `json:"name,omitempty"`
	// State: Output only. The state of the update.
	//
	// Possible values:
	//   "STATE_UNSPECIFIED" - Unspecified.
	//   "AVAILABLE" - The update is available to be applied.
	//   "APPLIED" - The update has been applied.
	//   "WITHDRAWN" - The update has been withdrawn by the service.
	State string `json:"state,omitempty"`
	// UpdateTime: The time the update was last updated.
	UpdateTime string `json:"updateTime,omitempty"`
	// ForceSendFields is a list of field names (e.g. "CreateTime") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "CreateTime") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadUpdate) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadUpdate
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions: Options to be set for
// the given created workload.
type GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions struct {
	// KajEnrollmentType: Optional. Specifies type of KAJ Enrollment if provided.
	//
	// Possible values:
	//   "KAJ_ENROLLMENT_TYPE_UNSPECIFIED" - KAJ Enrollment type is unspecified
	//   "KEY_ACCESS_TRANSPARENCY_OFF" - KAT sets External, Hardware, and Software
	// key feature logging only to TRUE.
	KajEnrollmentType string `json:"kajEnrollmentType,omitempty"`
	// ForceSendFields is a list of field names (e.g. "KajEnrollmentType") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "KajEnrollmentType") to include in
	// API requests with the JSON null value. By default, fields with empty values
	// are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleLongrunningListOperationsResponse: The response message for
// Operations.ListOperations.
type GoogleLongrunningListOperationsResponse struct {
	// NextPageToken: The standard List next-page token.
	NextPageToken string `json:"nextPageToken,omitempty"`
	// Operations: A list of operations that matches the specified filter in the
	// request.
	Operations []*GoogleLongrunningOperation `json:"operations,omitempty"`
	// Unreachable: Unordered list. Unreachable resources. Populated when the
	// request sets `ListOperationsRequest.return_partial_success` and reads across
	// collections. For example, when attempting to list all resources across all
	// supported locations.
	Unreachable []string `json:"unreachable,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "NextPageToken") to
	// unconditionally include in API requests. By default, fields with empty or
	// default values are omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "NextPageToken") to include in API
	// requests with the JSON null value. By default, fields with empty values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleLongrunningListOperationsResponse) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleLongrunningListOperationsResponse
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleLongrunningOperation: This resource represents a long-running
// operation that is the result of a network API call.
type GoogleLongrunningOperation struct {
	// Done: If the value is `false`, it means the operation is still in progress.
	// If `true`, the operation is completed, and either `error` or `response` is
	// available.
	Done bool `json:"done,omitempty"`
	// Error: The error result of the operation in case of failure or cancellation.
	Error *GoogleRpcStatus `json:"error,omitempty"`
	// Metadata: Service-specific metadata associated with the operation. It
	// typically contains progress information and common metadata such as create
	// time. Some services might not provide such metadata. Any method that returns
	// a long-running operation should document the metadata type, if any.
	Metadata googleapi.RawMessage `json:"metadata,omitempty"`
	// Name: The server-assigned name, which is only unique within the same service
	// that originally returns it. If you use the default HTTP mapping, the `name`
	// should be a resource name ending with `operations/{unique_id}`.
	Name string `json:"name,omitempty"`
	// Response: The normal, successful response of the operation. If the original
	// method returns no data on success, such as `Delete`, the response is
	// `google.protobuf.Empty`. If the original method is standard
	// `Get`/`Create`/`Update`, the response should be the resource. For other
	// methods, the response should have the type `XxxResponse`, where `Xxx` is the
	// original method name. For example, if the original method name is
	// `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.
	Response googleapi.RawMessage `json:"response,omitempty"`

	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
	// ForceSendFields is a list of field names (e.g. "Done") to unconditionally
	// include in API requests. By default, fields with empty or default values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Done") to include in API requests
	// with the JSON null value. By default, fields with empty values are omitted
	// from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleLongrunningOperation) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleLongrunningOperation
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

// GoogleProtobufEmpty: A generic empty message that you can re-use to avoid
// defining duplicated empty messages in your APIs. A typical example is to use
// it as the request or the response type of an API method. For instance:
// service Foo { rpc Bar(google.protobuf.Empty) returns
// (google.protobuf.Empty); }
type GoogleProtobufEmpty struct {
	// ServerResponse contains the HTTP response code and headers from the server.
	googleapi.ServerResponse `json:"-"`
}

// GoogleRpcStatus: The `Status` type defines a logical error model that is
// suitable for different programming environments, including REST APIs and RPC
// APIs. It is used by gRPC (https://github.com/grpc). Each `Status` message
// contains three pieces of data: error code, error message, and error details.
// You can find out more about this error model and how to work with it in the
// API Design Guide (https://cloud.google.com/apis/design/errors).
type GoogleRpcStatus struct {
	// Code: The status code, which should be an enum value of google.rpc.Code.
	Code int64 `json:"code,omitempty"`
	// Details: A list of messages that carry the error details. There is a common
	// set of message types for APIs to use.
	Details []googleapi.RawMessage `json:"details,omitempty"`
	// Message: A developer-facing error message, which should be in English. Any
	// user-facing error message should be localized and sent in the
	// google.rpc.Status.details field, or localized by the client.
	Message string `json:"message,omitempty"`
	// ForceSendFields is a list of field names (e.g. "Code") to unconditionally
	// include in API requests. By default, fields with empty or default values are
	// omitted from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-ForceSendFields for more
	// details.
	ForceSendFields []string `json:"-"`
	// NullFields is a list of field names (e.g. "Code") to include in API requests
	// with the JSON null value. By default, fields with empty values are omitted
	// from API requests. See
	// https://pkg.go.dev/google.golang.org/api#hdr-NullFields for more details.
	NullFields []string `json:"-"`
}

func (s GoogleRpcStatus) MarshalJSON() ([]byte, error) {
	type NoMethod GoogleRpcStatus
	return gensupport.MarshalJSON(NoMethod(s), s.ForceSendFields, s.NullFields)
}

type OrganizationsLocationsOperationsGetCall struct {
	s            *Service
	name         string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// Get: Gets the latest state of a long-running operation. Clients can use this
// method to poll the operation result at intervals as recommended by the API
// service.
//
// - name: The name of the operation resource.
func (r *OrganizationsLocationsOperationsService) Get(name string) *OrganizationsLocationsOperationsGetCall {
	c := &OrganizationsLocationsOperationsGetCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsOperationsGetCall) Fields(s ...googleapi.Field) *OrganizationsLocationsOperationsGetCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsOperationsGetCall) IfNoneMatch(entityTag string) *OrganizationsLocationsOperationsGetCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsOperationsGetCall) Context(ctx context.Context) *OrganizationsLocationsOperationsGetCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsOperationsGetCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsOperationsGetCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.operations.get", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.operations.get" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleLongrunningOperation.ServerResponse.Header or (if a response was
// returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsOperationsGetCall) Do(opts ...googleapi.CallOption) (*GoogleLongrunningOperation, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleLongrunningOperation{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.operations.get", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsOperationsListCall struct {
	s            *Service
	name         string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// List: Lists operations that match the specified filter in the request. If
// the server doesn't support this method, it returns `UNIMPLEMENTED`.
//
// - name: The name of the operation's parent resource.
func (r *OrganizationsLocationsOperationsService) List(name string) *OrganizationsLocationsOperationsListCall {
	c := &OrganizationsLocationsOperationsListCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Filter sets the optional parameter "filter": The standard list filter.
func (c *OrganizationsLocationsOperationsListCall) Filter(filter string) *OrganizationsLocationsOperationsListCall {
	c.urlParams_.Set("filter", filter)
	return c
}

// PageSize sets the optional parameter "pageSize": The standard list page
// size.
func (c *OrganizationsLocationsOperationsListCall) PageSize(pageSize int64) *OrganizationsLocationsOperationsListCall {
	c.urlParams_.Set("pageSize", fmt.Sprint(pageSize))
	return c
}

// PageToken sets the optional parameter "pageToken": The standard list page
// token.
func (c *OrganizationsLocationsOperationsListCall) PageToken(pageToken string) *OrganizationsLocationsOperationsListCall {
	c.urlParams_.Set("pageToken", pageToken)
	return c
}

// ReturnPartialSuccess sets the optional parameter "returnPartialSuccess":
// When set to `true`, operations that are reachable are returned as normal,
// and those that are unreachable are returned in the
// ListOperationsResponse.unreachable field. This can only be `true` when
// reading across collections. For example, when `parent` is set to
// "projects/example/locations/-". This field is not supported by default and
// will result in an `UNIMPLEMENTED` error if set unless explicitly documented
// otherwise in service or product specific documentation.
func (c *OrganizationsLocationsOperationsListCall) ReturnPartialSuccess(returnPartialSuccess bool) *OrganizationsLocationsOperationsListCall {
	c.urlParams_.Set("returnPartialSuccess", fmt.Sprint(returnPartialSuccess))
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsOperationsListCall) Fields(s ...googleapi.Field) *OrganizationsLocationsOperationsListCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsOperationsListCall) IfNoneMatch(entityTag string) *OrganizationsLocationsOperationsListCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsOperationsListCall) Context(ctx context.Context) *OrganizationsLocationsOperationsListCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsOperationsListCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsOperationsListCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}/operations")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.operations.list", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.operations.list" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleLongrunningListOperationsResponse.ServerResponse.Header or (if a
// response was returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsOperationsListCall) Do(opts ...googleapi.CallOption) (*GoogleLongrunningListOperationsResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleLongrunningListOperationsResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.operations.list", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

// Pages invokes f for each page of results.
// A non-nil error returned from f will halt the iteration.
// The provided context supersedes any context provided to the Context method.
func (c *OrganizationsLocationsOperationsListCall) Pages(ctx context.Context, f func(*GoogleLongrunningListOperationsResponse) error) error {
	c.ctx_ = ctx
	defer c.PageToken(c.urlParams_.Get("pageToken"))
	for {
		x, err := c.Do()
		if err != nil {
			return err
		}
		if err := f(x); err != nil {
			return err
		}
		if x.NextPageToken == "" {
			return nil
		}
		c.PageToken(x.NextPageToken)
	}
}

type OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall struct {
	s            *Service
	target       string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// AnalyzeWorkloadMove: Analyzes a hypothetical move of a source resource to a
// target workload to surface compliance risks. The analysis is best effort and
// is not guaranteed to be exhaustive.
//
//   - target: The resource ID of the folder-based destination workload. This
//     workload is where the source resource will hypothetically be moved to.
//     Specify the workload's relative resource name, formatted as:
//     "organizations/{ORGANIZATION_ID}/locations/{LOCATION_ID}/workloads/{WORKLOA
//     D_ID}" For example:
//     "organizations/123/locations/us-east1/workloads/assured-workload-2".
func (r *OrganizationsLocationsWorkloadsService) AnalyzeWorkloadMove(target string) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c := &OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.target = target
	return c
}

// AssetTypes sets the optional parameter "assetTypes": List of asset types to
// be analyzed, including and under the source resource. If empty, all assets
// are analyzed. The complete list of asset types is available here
// (https://cloud.google.com/asset-inventory/docs/supported-asset-types).
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) AssetTypes(assetTypes ...string) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.urlParams_.SetMulti("assetTypes", append([]string{}, assetTypes...))
	return c
}

// PageSize sets the optional parameter "pageSize": Page size. If a value is
// not specified, the default value of 10 is used. The maximum value is 50.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) PageSize(pageSize int64) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.urlParams_.Set("pageSize", fmt.Sprint(pageSize))
	return c
}

// PageToken sets the optional parameter "pageToken": The page token from the
// previous response. It needs to be passed in the second and following
// requests.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) PageToken(pageToken string) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.urlParams_.Set("pageToken", pageToken)
	return c
}

// Project sets the optional parameter "project": The source type is a project.
// Specify the project's relative resource name, formatted as either a project
// number or a project ID: "projects/{PROJECT_NUMBER}" or
// "projects/{PROJECT_ID}" For example: "projects/951040570662" when specifying
// a project number, or "projects/my-project-123" when specifying a project ID.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) Project(project string) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.urlParams_.Set("project", project)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) IfNoneMatch(entityTag string) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+target}:analyzeWorkloadMove")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"target": c.target,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.analyzeWorkloadMove", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.analyzeWorkloadMove" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse.ServerResponse.Head
// er or (if a response was returned at all) in
// error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check
// whether the returned error was because http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.analyzeWorkloadMove", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

// Pages invokes f for each page of results.
// A non-nil error returned from f will halt the iteration.
// The provided context supersedes any context provided to the Context method.
func (c *OrganizationsLocationsWorkloadsAnalyzeWorkloadMoveCall) Pages(ctx context.Context, f func(*GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse) error) error {
	c.ctx_ = ctx
	defer c.PageToken(c.urlParams_.Get("pageToken"))
	for {
		x, err := c.Do()
		if err != nil {
			return err
		}
		if err := f(x); err != nil {
			return err
		}
		if x.NextPageToken == "" {
			return nil
		}
		c.PageToken(x.NextPageToken)
	}
}

type OrganizationsLocationsWorkloadsCreateCall struct {
	s                                     *Service
	parent                                string
	googlecloudassuredworkloadsv1workload *GoogleCloudAssuredworkloadsV1Workload
	urlParams_                            gensupport.URLParams
	ctx_                                  context.Context
	header_                               http.Header
}

// Create: Creates Assured Workload.
//
//   - parent: The resource name of the new Workload's parent. Must be of the
//     form `organizations/{org_id}/locations/{location_id}`.
func (r *OrganizationsLocationsWorkloadsService) Create(parent string, googlecloudassuredworkloadsv1workload *GoogleCloudAssuredworkloadsV1Workload) *OrganizationsLocationsWorkloadsCreateCall {
	c := &OrganizationsLocationsWorkloadsCreateCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.parent = parent
	c.googlecloudassuredworkloadsv1workload = googlecloudassuredworkloadsv1workload
	return c
}

// ExternalId sets the optional parameter "externalId": A identifier associated
// with the workload and underlying projects which allows for the break down of
// billing costs for a workload. The value provided for the identifier will add
// a label to the workload and contained projects with the identifier as the
// value.
func (c *OrganizationsLocationsWorkloadsCreateCall) ExternalId(externalId string) *OrganizationsLocationsWorkloadsCreateCall {
	c.urlParams_.Set("externalId", externalId)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsCreateCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsCreateCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsCreateCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsCreateCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsCreateCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsCreateCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "application/json", c.header_)
	body, err := googleapi.WithoutDataWrapper.JSONBuffer(c.googlecloudassuredworkloadsv1workload)
	if err != nil {
		return nil, err
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+parent}/workloads")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("POST", urls, body)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"parent": c.parent,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.create", "request", internallog.HTTPRequest(req, body.Bytes()))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.create" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleLongrunningOperation.ServerResponse.Header or (if a response was
// returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsCreateCall) Do(opts ...googleapi.CallOption) (*GoogleLongrunningOperation, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleLongrunningOperation{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.create", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsDeleteCall struct {
	s          *Service
	name       string
	urlParams_ gensupport.URLParams
	ctx_       context.Context
	header_    http.Header
}

// Delete: Deletes the workload. Make sure that workload's direct children are
// already in a deleted state, otherwise the request will fail with a
// FAILED_PRECONDITION error. In addition to assuredworkloads.workload.delete
// permission, the user should also have orgpolicy.policy.set permission on the
// deleted folder to remove Assured Workloads OrgPolicies.
//
//   - name: The `name` field is used to identify the workload. Format:
//     organizations/{org_id}/locations/{location_id}/workloads/{workload_id}.
func (r *OrganizationsLocationsWorkloadsService) Delete(name string) *OrganizationsLocationsWorkloadsDeleteCall {
	c := &OrganizationsLocationsWorkloadsDeleteCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Etag sets the optional parameter "etag": The etag of the workload. If this
// is provided, it must match the server's etag.
func (c *OrganizationsLocationsWorkloadsDeleteCall) Etag(etag string) *OrganizationsLocationsWorkloadsDeleteCall {
	c.urlParams_.Set("etag", etag)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsDeleteCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsDeleteCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsDeleteCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsDeleteCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsDeleteCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsDeleteCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("DELETE", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.delete", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.delete" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleProtobufEmpty.ServerResponse.Header or (if a response was returned at
// all) in error.(*googleapi.Error).Header. Use googleapi.IsNotModified to
// check whether the returned error was because http.StatusNotModified was
// returned.
func (c *OrganizationsLocationsWorkloadsDeleteCall) Do(opts ...googleapi.CallOption) (*GoogleProtobufEmpty, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleProtobufEmpty{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.delete", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall struct {
	s          *Service
	name       string
	urlParams_ gensupport.URLParams
	ctx_       context.Context
	header_    http.Header
}

// EnableComplianceUpdates: This endpoint enables Assured Workloads service to
// offer compliance updates for the folder based assured workload. It sets up
// an Assured Workloads Service Agent, having permissions to read compliance
// controls (for example: Org Policies) applied on the workload. The caller
// must have `resourcemanager.folders.getIamPolicy` and
// `resourcemanager.folders.setIamPolicy` permissions on the assured workload
// folder.
//
//   - name: The `name` field is used to identify the workload. Format:
//     organizations/{org_id}/locations/{location_id}/workloads/{workload_id}.
func (r *OrganizationsLocationsWorkloadsService) EnableComplianceUpdates(name string) *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall {
	c := &OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}:enableComplianceUpdates")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("PUT", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.enableComplianceUpdates", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.enableComplianceUpdates" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse.ServerResponse.
// Header or (if a response was returned at all) in
// error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check
// whether the returned error was because http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsEnableComplianceUpdatesCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.enableComplianceUpdates", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsEnableResourceMonitoringCall struct {
	s          *Service
	name       string
	urlParams_ gensupport.URLParams
	ctx_       context.Context
	header_    http.Header
}

// EnableResourceMonitoring: Enable resource violation monitoring for a
// workload.
//
//   - name: The `name` field is used to identify the workload. Format:
//     organizations/{org_id}/locations/{location_id}/workloads/{workload_id}.
func (r *OrganizationsLocationsWorkloadsService) EnableResourceMonitoring(name string) *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall {
	c := &OrganizationsLocationsWorkloadsEnableResourceMonitoringCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}:enableResourceMonitoring")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("POST", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.enableResourceMonitoring", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.enableResourceMonitoring" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse.ServerResponse
// .Header or (if a response was returned at all) in
// error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check
// whether the returned error was because http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsEnableResourceMonitoringCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.enableResourceMonitoring", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsGetCall struct {
	s            *Service
	name         string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// Get: Gets Assured Workload associated with a CRM Node
//
//   - name: The resource name of the Workload to fetch. This is the workloads's
//     relative path in the API, formatted as
//     "organizations/{organization_id}/locations/{location_id}/workloads/{workloa
//     d_id}". For example,
//     "organizations/123/locations/us-east1/workloads/assured-workload-1".
func (r *OrganizationsLocationsWorkloadsService) Get(name string) *OrganizationsLocationsWorkloadsGetCall {
	c := &OrganizationsLocationsWorkloadsGetCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsGetCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsGetCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsWorkloadsGetCall) IfNoneMatch(entityTag string) *OrganizationsLocationsWorkloadsGetCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsGetCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsGetCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsGetCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsGetCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.get", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.get" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1Workload.ServerResponse.Header or (if a
// response was returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsGetCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1Workload, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1Workload{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.get", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsListCall struct {
	s            *Service
	parent       string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// List: Lists Assured Workloads under a CRM Node.
//
//   - parent: Parent Resource to list workloads from. Must be of the form
//     `organizations/{org_id}/locations/{location}`.
func (r *OrganizationsLocationsWorkloadsService) List(parent string) *OrganizationsLocationsWorkloadsListCall {
	c := &OrganizationsLocationsWorkloadsListCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.parent = parent
	return c
}

// Filter sets the optional parameter "filter": A custom filter for filtering
// by properties of a workload. At this time, only filtering by labels is
// supported.
func (c *OrganizationsLocationsWorkloadsListCall) Filter(filter string) *OrganizationsLocationsWorkloadsListCall {
	c.urlParams_.Set("filter", filter)
	return c
}

// PageSize sets the optional parameter "pageSize": Page size.
func (c *OrganizationsLocationsWorkloadsListCall) PageSize(pageSize int64) *OrganizationsLocationsWorkloadsListCall {
	c.urlParams_.Set("pageSize", fmt.Sprint(pageSize))
	return c
}

// PageToken sets the optional parameter "pageToken": Page token returned from
// previous request. Page token contains context from previous request. Page
// token needs to be passed in the second and following requests.
func (c *OrganizationsLocationsWorkloadsListCall) PageToken(pageToken string) *OrganizationsLocationsWorkloadsListCall {
	c.urlParams_.Set("pageToken", pageToken)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsListCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsListCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsWorkloadsListCall) IfNoneMatch(entityTag string) *OrganizationsLocationsWorkloadsListCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsListCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsListCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsListCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsListCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+parent}/workloads")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"parent": c.parent,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.list", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.list" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1ListWorkloadsResponse.ServerResponse.Header or
// (if a response was returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsListCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1ListWorkloadsResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1ListWorkloadsResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.list", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

// Pages invokes f for each page of results.
// A non-nil error returned from f will halt the iteration.
// The provided context supersedes any context provided to the Context method.
func (c *OrganizationsLocationsWorkloadsListCall) Pages(ctx context.Context, f func(*GoogleCloudAssuredworkloadsV1ListWorkloadsResponse) error) error {
	c.ctx_ = ctx
	defer c.PageToken(c.urlParams_.Get("pageToken"))
	for {
		x, err := c.Do()
		if err != nil {
			return err
		}
		if err := f(x); err != nil {
			return err
		}
		if x.NextPageToken == "" {
			return nil
		}
		c.PageToken(x.NextPageToken)
	}
}

type OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall struct {
	s                                                            *Service
	name                                                         string
	googlecloudassuredworkloadsv1mutatepartnerpermissionsrequest *GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest
	urlParams_                                                   gensupport.URLParams
	ctx_                                                         context.Context
	header_                                                      http.Header
}

// MutatePartnerPermissions: Update the permissions settings for an existing
// partner workload. For force updates don't set etag field in the Workload.
// Only one update operation per workload can be in progress.
//
//   - name: The `name` field is used to identify the workload. Format:
//     organizations/{org_id}/locations/{location_id}/workloads/{workload_id}.
func (r *OrganizationsLocationsWorkloadsService) MutatePartnerPermissions(name string, googlecloudassuredworkloadsv1mutatepartnerpermissionsrequest *GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest) *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall {
	c := &OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	c.googlecloudassuredworkloadsv1mutatepartnerpermissionsrequest = googlecloudassuredworkloadsv1mutatepartnerpermissionsrequest
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "application/json", c.header_)
	body, err := googleapi.WithoutDataWrapper.JSONBuffer(c.googlecloudassuredworkloadsv1mutatepartnerpermissionsrequest)
	if err != nil {
		return nil, err
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}:mutatePartnerPermissions")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("PATCH", urls, body)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.mutatePartnerPermissions", "request", internallog.HTTPRequest(req, body.Bytes()))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.mutatePartnerPermissions" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1Workload.ServerResponse.Header or (if a
// response was returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsMutatePartnerPermissionsCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1Workload, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1Workload{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.mutatePartnerPermissions", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsPatchCall struct {
	s                                     *Service
	name                                  string
	googlecloudassuredworkloadsv1workload *GoogleCloudAssuredworkloadsV1Workload
	urlParams_                            gensupport.URLParams
	ctx_                                  context.Context
	header_                               http.Header
}

// Patch: Updates an existing workload. Currently allows updating of workload
// display_name and labels. For force updates don't set etag field in the
// Workload. Only one update operation per workload can be in progress.
//
//   - name: Optional. The resource name of the workload. Format:
//     organizations/{organization}/locations/{location}/workloads/{workload}
//     Read-only.
func (r *OrganizationsLocationsWorkloadsService) Patch(name string, googlecloudassuredworkloadsv1workload *GoogleCloudAssuredworkloadsV1Workload) *OrganizationsLocationsWorkloadsPatchCall {
	c := &OrganizationsLocationsWorkloadsPatchCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	c.googlecloudassuredworkloadsv1workload = googlecloudassuredworkloadsv1workload
	return c
}

// UpdateMask sets the optional parameter "updateMask": Required. The list of
// fields to be updated.
func (c *OrganizationsLocationsWorkloadsPatchCall) UpdateMask(updateMask string) *OrganizationsLocationsWorkloadsPatchCall {
	c.urlParams_.Set("updateMask", updateMask)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsPatchCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsPatchCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsPatchCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsPatchCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsPatchCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsPatchCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "application/json", c.header_)
	body, err := googleapi.WithoutDataWrapper.JSONBuffer(c.googlecloudassuredworkloadsv1workload)
	if err != nil {
		return nil, err
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("PATCH", urls, body)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.patch", "request", internallog.HTTPRequest(req, body.Bytes()))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.patch" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1Workload.ServerResponse.Header or (if a
// response was returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsPatchCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1Workload, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1Workload{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.patch", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall struct {
	s                                                            *Service
	name                                                         string
	googlecloudassuredworkloadsv1restrictallowedresourcesrequest *GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest
	urlParams_                                                   gensupport.URLParams
	ctx_                                                         context.Context
	header_                                                      http.Header
}

// RestrictAllowedResources: Restrict the list of resources allowed in the
// Workload environment. The current list of allowed products can be found at
// https://cloud.google.com/assured-workloads/docs/supported-products In
// addition to assuredworkloads.workload.update permission, the user should
// also have orgpolicy.policy.set permission on the folder resource to use this
// functionality.
//
//   - name: The resource name of the Workload. This is the workloads's relative
//     path in the API, formatted as
//     "organizations/{organization_id}/locations/{location_id}/workloads/{workloa
//     d_id}". For example,
//     "organizations/123/locations/us-east1/workloads/assured-workload-1".
func (r *OrganizationsLocationsWorkloadsService) RestrictAllowedResources(name string, googlecloudassuredworkloadsv1restrictallowedresourcesrequest *GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest) *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall {
	c := &OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	c.googlecloudassuredworkloadsv1restrictallowedresourcesrequest = googlecloudassuredworkloadsv1restrictallowedresourcesrequest
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "application/json", c.header_)
	body, err := googleapi.WithoutDataWrapper.JSONBuffer(c.googlecloudassuredworkloadsv1restrictallowedresourcesrequest)
	if err != nil {
		return nil, err
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}:restrictAllowedResources")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("POST", urls, body)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.restrictAllowedResources", "request", internallog.HTTPRequest(req, body.Bytes()))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.restrictAllowedResources" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse.ServerResponse
// .Header or (if a response was returned at all) in
// error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check
// whether the returned error was because http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsRestrictAllowedResourcesCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.restrictAllowedResources", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsUpdatesApplyCall struct {
	s                                                       *Service
	name                                                    string
	googlecloudassuredworkloadsv1applyworkloadupdaterequest *GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest
	urlParams_                                              gensupport.URLParams
	ctx_                                                    context.Context
	header_                                                 http.Header
}

// Apply: This endpoint creates a new operation to apply the given update.
//
//   - name: The resource name of the update. Format:
//     organizations/{org_id}/locations/{location_id}/workloads/{workload_id}/upda
//     tes/{update_id}.
func (r *OrganizationsLocationsWorkloadsUpdatesService) Apply(name string, googlecloudassuredworkloadsv1applyworkloadupdaterequest *GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest) *OrganizationsLocationsWorkloadsUpdatesApplyCall {
	c := &OrganizationsLocationsWorkloadsUpdatesApplyCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	c.googlecloudassuredworkloadsv1applyworkloadupdaterequest = googlecloudassuredworkloadsv1applyworkloadupdaterequest
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsUpdatesApplyCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsUpdatesApplyCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsUpdatesApplyCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsUpdatesApplyCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsUpdatesApplyCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsUpdatesApplyCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "application/json", c.header_)
	body, err := googleapi.WithoutDataWrapper.JSONBuffer(c.googlecloudassuredworkloadsv1applyworkloadupdaterequest)
	if err != nil {
		return nil, err
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}:apply")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("POST", urls, body)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.updates.apply", "request", internallog.HTTPRequest(req, body.Bytes()))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.updates.apply" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleLongrunningOperation.ServerResponse.Header or (if a response was
// returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsUpdatesApplyCall) Do(opts ...googleapi.CallOption) (*GoogleLongrunningOperation, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleLongrunningOperation{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.updates.apply", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsUpdatesListCall struct {
	s            *Service
	parent       string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// List: This endpoint lists all updates for the given workload.
//
//   - parent:
//     organizations/{org_id}/locations/{location_id}/workloads/{workload_id}.
func (r *OrganizationsLocationsWorkloadsUpdatesService) List(parent string) *OrganizationsLocationsWorkloadsUpdatesListCall {
	c := &OrganizationsLocationsWorkloadsUpdatesListCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.parent = parent
	return c
}

// PageSize sets the optional parameter "pageSize": Page size. The default
// value is 20 and the max allowed value is 100.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) PageSize(pageSize int64) *OrganizationsLocationsWorkloadsUpdatesListCall {
	c.urlParams_.Set("pageSize", fmt.Sprint(pageSize))
	return c
}

// PageToken sets the optional parameter "pageToken": Page token returned from
// previous request.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) PageToken(pageToken string) *OrganizationsLocationsWorkloadsUpdatesListCall {
	c.urlParams_.Set("pageToken", pageToken)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsUpdatesListCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) IfNoneMatch(entityTag string) *OrganizationsLocationsWorkloadsUpdatesListCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsUpdatesListCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsUpdatesListCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+parent}/updates")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"parent": c.parent,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.updates.list", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.updates.list" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse.ServerResponse.Head
// er or (if a response was returned at all) in
// error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check
// whether the returned error was because http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.updates.list", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

// Pages invokes f for each page of results.
// A non-nil error returned from f will halt the iteration.
// The provided context supersedes any context provided to the Context method.
func (c *OrganizationsLocationsWorkloadsUpdatesListCall) Pages(ctx context.Context, f func(*GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse) error) error {
	c.ctx_ = ctx
	defer c.PageToken(c.urlParams_.Get("pageToken"))
	for {
		x, err := c.Do()
		if err != nil {
			return err
		}
		if err := f(x); err != nil {
			return err
		}
		if x.NextPageToken == "" {
			return nil
		}
		c.PageToken(x.NextPageToken)
	}
}

type OrganizationsLocationsWorkloadsViolationsAcknowledgeCall struct {
	s                                                        *Service
	name                                                     string
	googlecloudassuredworkloadsv1acknowledgeviolationrequest *GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest
	urlParams_                                               gensupport.URLParams
	ctx_                                                     context.Context
	header_                                                  http.Header
}

// Acknowledge: Acknowledges an existing violation. By acknowledging a
// violation, users acknowledge the existence of a compliance violation in
// their workload and decide to ignore it due to a valid business
// justification. Acknowledgement is a permanent operation and it cannot be
// reverted.
//
//   - name: The resource name of the Violation to acknowledge. Format:
//     organizations/{organization}/locations/{location}/workloads/{workload}/viol
//     ations/{violation}.
func (r *OrganizationsLocationsWorkloadsViolationsService) Acknowledge(name string, googlecloudassuredworkloadsv1acknowledgeviolationrequest *GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest) *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall {
	c := &OrganizationsLocationsWorkloadsViolationsAcknowledgeCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	c.googlecloudassuredworkloadsv1acknowledgeviolationrequest = googlecloudassuredworkloadsv1acknowledgeviolationrequest
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "application/json", c.header_)
	body, err := googleapi.WithoutDataWrapper.JSONBuffer(c.googlecloudassuredworkloadsv1acknowledgeviolationrequest)
	if err != nil {
		return nil, err
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}:acknowledge")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("POST", urls, body)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.violations.acknowledge", "request", internallog.HTTPRequest(req, body.Bytes()))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.violations.acknowledge" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse.ServerResponse.Hea
// der or (if a response was returned at all) in
// error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check
// whether the returned error was because http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsViolationsAcknowledgeCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.violations.acknowledge", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsViolationsGetCall struct {
	s            *Service
	name         string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// Get: Retrieves Assured Workload Violation based on ID.
//
//   - name: The resource name of the Violation to fetch (ie. Violation.name).
//     Format:
//     organizations/{organization}/locations/{location}/workloads/{workload}/viol
//     ations/{violation}.
func (r *OrganizationsLocationsWorkloadsViolationsService) Get(name string) *OrganizationsLocationsWorkloadsViolationsGetCall {
	c := &OrganizationsLocationsWorkloadsViolationsGetCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.name = name
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsViolationsGetCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsViolationsGetCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsWorkloadsViolationsGetCall) IfNoneMatch(entityTag string) *OrganizationsLocationsWorkloadsViolationsGetCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsViolationsGetCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsViolationsGetCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsViolationsGetCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsViolationsGetCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+name}")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"name": c.name,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.violations.get", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.violations.get" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1Violation.ServerResponse.Header or (if a
// response was returned at all) in error.(*googleapi.Error).Header. Use
// googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsViolationsGetCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1Violation, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1Violation{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.violations.get", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

type OrganizationsLocationsWorkloadsViolationsListCall struct {
	s            *Service
	parent       string
	urlParams_   gensupport.URLParams
	ifNoneMatch_ string
	ctx_         context.Context
	header_      http.Header
}

// List: Lists the Violations in the AssuredWorkload Environment. Callers may
// also choose to read across multiple Workloads as per AIP-159
// (https://google.aip.dev/159) by using '-' (the hyphen or dash character) as
// a wildcard character instead of workload-id in the parent. Format
// `organizations/{org_id}/locations/{location}/workloads/-`
//
//   - parent: The Workload name. Format
//     `organizations/{org_id}/locations/{location}/workloads/{workload}`.
func (r *OrganizationsLocationsWorkloadsViolationsService) List(parent string) *OrganizationsLocationsWorkloadsViolationsListCall {
	c := &OrganizationsLocationsWorkloadsViolationsListCall{s: r.s, urlParams_: make(gensupport.URLParams)}
	c.parent = parent
	return c
}

// Filter sets the optional parameter "filter": A custom filter for filtering
// by the Violations properties.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) Filter(filter string) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.urlParams_.Set("filter", filter)
	return c
}

// IntervalEndTime sets the optional parameter "interval.endTime": The end of
// the time window.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) IntervalEndTime(intervalEndTime string) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.urlParams_.Set("interval.endTime", intervalEndTime)
	return c
}

// IntervalStartTime sets the optional parameter "interval.startTime": The
// start of the time window.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) IntervalStartTime(intervalStartTime string) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.urlParams_.Set("interval.startTime", intervalStartTime)
	return c
}

// PageSize sets the optional parameter "pageSize": Page size.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) PageSize(pageSize int64) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.urlParams_.Set("pageSize", fmt.Sprint(pageSize))
	return c
}

// PageToken sets the optional parameter "pageToken": Page token returned from
// previous request.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) PageToken(pageToken string) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.urlParams_.Set("pageToken", pageToken)
	return c
}

// Fields allows partial responses to be retrieved. See
// https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more
// details.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) Fields(s ...googleapi.Field) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.urlParams_.Set("fields", googleapi.CombineFields(s))
	return c
}

// IfNoneMatch sets an optional parameter which makes the operation fail if the
// object's ETag matches the given value. This is useful for getting updates
// only after the object has changed since the last request.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) IfNoneMatch(entityTag string) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.ifNoneMatch_ = entityTag
	return c
}

// Context sets the context to be used in this call's Do method.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) Context(ctx context.Context) *OrganizationsLocationsWorkloadsViolationsListCall {
	c.ctx_ = ctx
	return c
}

// Header returns a http.Header that can be modified by the caller to add
// headers to the request.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) Header() http.Header {
	if c.header_ == nil {
		c.header_ = make(http.Header)
	}
	return c.header_
}

func (c *OrganizationsLocationsWorkloadsViolationsListCall) doRequest(alt string) (*http.Response, error) {
	reqHeaders := gensupport.SetHeaders(c.s.userAgent(), "", c.header_)
	if c.ifNoneMatch_ != "" {
		reqHeaders.Set("If-None-Match", c.ifNoneMatch_)
	}
	c.urlParams_.Set("alt", alt)
	c.urlParams_.Set("prettyPrint", "false")
	urls := googleapi.ResolveRelative(c.s.BasePath, "v1/{+parent}/violations")
	urls += "?" + c.urlParams_.Encode()
	req, err := http.NewRequest("GET", urls, nil)
	if err != nil {
		return nil, err
	}
	req.Header = reqHeaders
	googleapi.Expand(req.URL, map[string]string{
		"parent": c.parent,
	})
	c.s.logger.DebugContext(c.ctx_, "api request", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.violations.list", "request", internallog.HTTPRequest(req, nil))
	return gensupport.SendRequest(c.ctx_, c.s.client, req)
}

// Do executes the "assuredworkloads.organizations.locations.workloads.violations.list" call.
// Any non-2xx status code is an error. Response headers are in either
// *GoogleCloudAssuredworkloadsV1ListViolationsResponse.ServerResponse.Header
// or (if a response was returned at all) in error.(*googleapi.Error).Header.
// Use googleapi.IsNotModified to check whether the returned error was because
// http.StatusNotModified was returned.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) Do(opts ...googleapi.CallOption) (*GoogleCloudAssuredworkloadsV1ListViolationsResponse, error) {
	gensupport.SetOptions(c.urlParams_, opts...)
	res, err := c.doRequest("json")
	if res != nil && res.StatusCode == http.StatusNotModified {
		if res.Body != nil {
			res.Body.Close()
		}
		return nil, gensupport.WrapError(&googleapi.Error{
			Code:   res.StatusCode,
			Header: res.Header,
		})
	}
	if err != nil {
		return nil, err
	}
	defer googleapi.CloseBody(res)
	if err := googleapi.CheckResponse(res); err != nil {
		return nil, gensupport.WrapError(err)
	}
	ret := &GoogleCloudAssuredworkloadsV1ListViolationsResponse{
		ServerResponse: googleapi.ServerResponse{
			Header:         res.Header,
			HTTPStatusCode: res.StatusCode,
		},
	}
	target := &ret
	b, err := gensupport.DecodeResponseBytes(target, res)
	if err != nil {
		return nil, err
	}
	c.s.logger.DebugContext(c.ctx_, "api response", "serviceName", apiName, "rpcName", "assuredworkloads.organizations.locations.workloads.violations.list", "response", internallog.HTTPResponse(res, b))
	return ret, nil
}

// Pages invokes f for each page of results.
// A non-nil error returned from f will halt the iteration.
// The provided context supersedes any context provided to the Context method.
func (c *OrganizationsLocationsWorkloadsViolationsListCall) Pages(ctx context.Context, f func(*GoogleCloudAssuredworkloadsV1ListViolationsResponse) error) error {
	c.ctx_ = ctx
	defer c.PageToken(c.urlParams_.Get("pageToken"))
	for {
		x, err := c.Do()
		if err != nil {
			return err
		}
		if err := f(x); err != nil {
			return err
		}
		if x.NextPageToken == "" {
			return nil
		}
		c.PageToken(x.NextPageToken)
	}
}
